#ifndef __CTRLENAB_H
#define __CTRLENAB_H

#ifndef __CHECKS_H
#include <checks.h>
#endif

// This is the class declaration for TControlEnabler.  You derive your own
// custom enablers from it by overriding condition() to return TRUE for cases
// when the control supplied to the ctor should be enabled.  You can use
// getDialog() to get a pointer to the TCEDialog so you can query the states
// of the other controls or use TYPESAFE_DOWNCAST to get at your TCEDialog-
// derived class's data.

class _export TCEDialog;

class TControlEnabler
{
	public:
		friend class TCEDialog;

		TControlEnabler(int ctrlId) : id(ctrlId) {}
		virtual ~TControlEnabler() {}
		int operator==(const TControlEnabler& toCompare) const
		{
			PRECONDITION(&toCompare!=NULL);
			return ((theDlg==toCompare.theDlg)&&(id==toCompare.id));
		}

	protected:
		virtual int condition() const { return 1; }
		int getId() const { return id; }
		const TCEDialog* getDialog() const
		{
			PRECONDITION(theDlg!=NULL);
			return theDlg;
		}

	private:
		void poll() const;
		int id;
		TCEDialog* theDlg;
};

#endif