//	Copyright  1995 by Dan Nelson. All Rights Reserved.

#ifndef __HINT_H
#define __HINT_H

#include <owl\messageb.h>
#include <cstring.h>

#ifndef __CHECKS_H
#include <checks.h>
#endif

// This header defines the class THint which is derived virtually from
// TEventHandler and becomes a base for TControlHint which merely mixes
// the functionality of TControl and THint.  TControlHints are used to
// associate text strings and a MessageBar on which to display them with
// a control in a dialog.  They are then installed into a THintDialog
// using its installHint() function.  At that point, the control's fly-by
// hints will be automatic.

class _export THint : virtual public TEventHandler
{
	public:
		THint(const string& hint, TMessageBar* cb) : myHint(hint),
			myBar(cb), hintUp(FALSE) {}
		void putHint()
		{
			if(myBar&&!hintUp)
			{
				myBar->SetHintText(myHint.c_str());
				hintUp = TRUE;
			}
		}
		void takeHint()
		{
			if(myBar&&hintUp)
			{
				myBar->SetHintText(NULL);
				hintUp = FALSE;
			}
		}
		int operator==(const THint& toCompare)
		{
			PRECONDITION(&toCompare!=NULL);
			return (
					(myHint==toCompare.myHint) &&
					(myBar==toCompare.myBar)
					);
		}
		void setBar(TMessageBar* newBar) { myBar = newBar; }

	private:
		string myHint;
		TMessageBar* myBar;
		BOOL hintUp;
};

#endif