//	Copyright  1995 by Dan Nelson. All Rights Reserved.

// This header defines the TSmartPointer class for pointers that
// do their own cleanup.  TSmartPointers always own what they point to
// which must be created with new.  The object is delete when the
// pointer goes out of scope or is re-assigned.  To explicity delete
// the object, you must use the Delete() member func.  TSmartPointers
// can be cast to either type T or type T*.  The conversion is automatic
// in function calls so they can be args of these types.  They have
// assignment and relational operators.  When you create a TSmartPointer
// to point to an array, set the second parameter in the ctor to TRUE
// so operator delete[] will be used to delete it.  It must then always
// be re-assigned to an array, or changed with isVect = FALSE.

#ifndef __SMRTPNTR_H
#define __SMRTPNTR_H

#ifndef __CHECKS_H
#include <checks.h>
#endif

template<class T> class TSmartPointer
{
	public:
		T* ptr;
		int isVect;

		TSmartPointer(T* p, int v = 0) : ptr(p), isVect(v)
			{ PRECONDITION(ptr!=NULL); }
		TSmartPointer(const TSmartPointer& p, int v = 0) : ptr(p.ptr),
			isVect(v) { PRECONDITION(ptr!=NULL); }
		TSmartPointer() : ptr(0), isVect(0) {}
		virtual ~TSmartPointer() { if(ptr)
									{
										if(isVect) delete[] ptr;
										else delete ptr;
									}
								 }
		operator T*() { return ptr; }
		operator T&() { PRECONDITION(ptr!=NULL); return *ptr; }
		int operator==(const TSmartPointer& toCompare)
			{ return ptr==toCompare.ptr; }
		int operator!=(const TSmartPointer& toCompare)
			{ return !(*this==toCompare); }
		const TSmartPointer& operator=(const TSmartPointer& toAssign)
		{
				if(ptr)
				{
					if(isVect) delete[] ptr;
					else delete ptr;
				}
				ptr = toAssign.ptr;
				return toAssign;
		}
		const T* operator=(T* const toAssign)
		{
				if(ptr)
				{
					if(isVect) delete[] ptr;
					else delete ptr;
				}
				ptr = toAssign;
				return toAssign;
		}
		void Delete() { *this = 0; }
};

#endif