//	Copyright  1995 by Dan Nelson. All Rights Reserved.

// TCEDialog source moudule.  To use TControlEnabler you have to derive your
// dialog class from TCEDialog rather than TDialog.  Then you derive your
// control enabler publicly from TControlEnabler and overload its
// "condition()" member function to return TRUE for cases where the control
// should be enabled.  Then you use the "installEnabler" member of TCEDialog
// to install the enabler.  The enabler object should be created with new,
// and you should not delete.  In fact, there is no reason to keep a pointer
// to it after it is installed.  TCEDialog does all of the work from there,
// and automatically deletes in in the dtor.

// You can use TControlEnabler's "getDialog()" member function to get a
// pointer to the TCEDialog object so you can query other controls using
// TDialog::GetDlgItem(id).

#include <owl\owlpch.h>
#pragma hdrstop

#include "c:\dansapps\classes\headers\tcedialg.h"

TCEDialog::TCEDialog (TWindow* parent, TResId resId, TModule* module):
	TDialog(parent, resId, module)
{
	eList = new TEnablerList;
}

TCEDialog::~TCEDialog ()
{
	Destroy();
	CHECK(eList!=NULL);
	if(eList->GetItemsInContainer())
	{
		TEnablerIterator i(*eList);

		while(i)
		{
			CHECK(i.Current()!=NULL);
			delete i++;
		}
	}
	delete eList;
}

void TCEDialog::installEnabler(TControlEnabler* toInstall)
{
	PRECONDITION(toInstall!=NULL);
	toInstall->theDlg = this;
	eList->Add(toInstall);
}


void TCEDialog::DoNotify()
{
	TEnablerIterator i(*eList);
	while(i)
	{
		CHECK(i.Current()!=NULL);
		(i++)->poll();
	}
}

BOOL TCEDialog::DialogFunction (UINT message, WPARAM wParam, LPARAM lparam)
{
	BOOL result;

	result = TDialog::DialogFunction(message, wParam, lparam);
	if(message!=WM_COMMAND) return result;

	// If we get any of the following child notifications, we will query
	// all TControlEnablers to see if the states of any controls have
	// changed.

	if(
	(HIWORD(lparam)==BN_CLICKED) ||
	(HIWORD(lparam)==BN_HILITE) ||
	(HIWORD(lparam)==CBN_EDITCHANGE) ||
	(HIWORD(lparam)==CBN_SELCHANGE) ||
	(HIWORD(lparam)==CBN_CLOSEUP) ||
	(HIWORD(lparam)==CBN_DROPDOWN) ||
	(HIWORD(lparam)==CBN_KILLFOCUS) ||
	(HIWORD(lparam)==CBN_SELCHANGE) ||
	(HIWORD(lparam)==CBN_SETFOCUS) ||
	(HIWORD(lparam)==EN_CHANGE) ||
	(HIWORD(lparam)==EN_KILLFOCUS) ||
	(HIWORD(lparam)==EN_SETFOCUS) ||
	(HIWORD(lparam)==LBN_KILLFOCUS) ||
	(HIWORD(lparam)==LBN_SELCANCEL) ||
	(HIWORD(lparam)==LBN_SELCHANGE) ||
	(HIWORD(lparam)==LBN_SETFOCUS)
	)
		DoNotify();

	return result;
}

